@@ -119,6 +119,11 @@ void  panel_background_change_region     (PanelBackground     *background,
 char *panel_background_make_string       (PanelBackground     *background,
 					  int                  x,
 					  int                  y);
+
+PanelBackgroundType  panel_background_get_type   (PanelBackground *background);
+const PanelColor    *panel_background_get_color  (PanelBackground *background);
+const GdkPixmap     *panel_background_get_pixmap (PanelBackground *background);
+
 PanelBackgroundType
       panel_background_effective_type    (PanelBackground     *background);
 
