@@ -34,6 +34,29 @@
 #include "panel-globals.h"
 #include "launcher.h"
 
+void
+panel_launch_desktop_file (const char  *desktop_file,
+			   const char  *fallback_exec,
+			   GdkScreen   *screen,
+			   GError     **error)
+{
+	GnomeDesktopItem *ditem;
+
+	ditem = gnome_desktop_item_new_from_basename ("gmenu-simple-editor.desktop", 0, NULL);
+	if (ditem == NULL) {
+		char *argv [2] = {(char *)fallback_exec, NULL};
+
+		gdk_spawn_on_screen (screen, NULL, argv, NULL,
+				     G_SPAWN_SEARCH_PATH,
+				     NULL, NULL, NULL, error);
+		return;
+	}
+
+	panel_ditem_launch (ditem, NULL, 0, screen, error);
+
+	gnome_desktop_item_unref (ditem);
+}
+
 int
 panel_ditem_launch (GnomeDesktopItem             *item,
 		    GList                        *file_list,
